@@ -64,7 +64,6 @@ typedef struct radio_preset_st radio_preset;
 
 typedef struct {
 	GtkWidget*		outer_box;
-	GtkWidget*		box;
 	GtkWidget*		ebox;
 	GtkWidget*		label;
 	GtkWidget*		signal_bar;
@@ -78,9 +77,8 @@ typedef struct {
 	gboolean		on;
 	gboolean		show_label;
 	gboolean		show_signal;
-	gboolean		show_label_when_off;
 	gboolean		resolve_presets_in_label;
-	gboolean		show_signal_graphical;
+	gboolean		use_graphics;
 	gboolean		auto_update_display;
 	gint			freq;
 	char			device [MAX_DEVICE_NAME_LENGTH];
